package com.sinognss.bluetooth;

import android.bluetooth.BluetoothDevice;
import com.sinognss.sm.comm.IRawDataListener;
import com.sinognss.sm.comm.ICommStatusListener;

/**
 * 蓝牙管理接口
 * 客户端得到此代理后必须先调用{@link #init(IBinder)}初始化
 * @author Canney
 * @date 2016年3月14日 下午4:17:56
 *
 */
interface BluetoothService {

	/**
	 * 连接设备
	 * @param address bluetooth MAC
	 * @author Canney
	 * @date 2016年3月14日 下午4:19:06
	 */
	void connect(String address);

    /**
	 * 获取当前连接的设备
	 * @ device
	 * @author Canney
	 * @date 2017年11月14日 下午4:19:06
	 */
	BluetoothDevice getConnectedDevice();

	/**
	 * 断开设备
	 *
	 * @author Canney
	 * @date 2016年3月14日 下午4:19:22
	 */
	void disconnect();

	/**
	 * 发送指令
	 * @param cmd
	 * @author Canney
	 * @date 2016年3月14日 下午4:19:56
	 */
	boolean send(in byte[] data);

	/**
	 * 当前连接状态
	 * @return
	 * @author Canney
	 * @date 2016年3月14日 下午4:20:05
	 */
	boolean isConnected();

	/**
	 * 取消连接
	 */
	void cancel();

	boolean register(ICommStatusListener listener);

	boolean unregister(ICommStatusListener listener);

    /**
	 * 注册原始数据监听
	 */
	boolean registerRawDataListener(IRawDataListener listener);

	/**
	 * 解除原始数据监听
	 */
	boolean unregisterRawDataListener(IRawDataListener listener);
}
